AshVersioned.Resource.Archive (ash_versioned v0.1.0)

Represents the archive entity declared inside the versioning DSL section of AshVersioned.Resource.

A resource is archivable when the archive entity is declared.

Summary

Types

t()

@type t() :: %AshVersioned.Resource.Archive{
  __spark_metadata__: term(),
  action: atom() | false,
  attribute: atom(),
  define_attribute?: boolean(),
  exclude_read_actions: [atom()],
  read_action: atom() | false,
  source: atom() | nil,
  unarchive: atom() | false
}