AshVersioned. Preparations. FilterLatest
(ash_versioned v0.1.0)
Scopes read actions to include latest_attribute == true, and if archive is declared
on the resource, archived == false.
The resource history_action is always excluded from both latest and archive
filtering; user-declared actions can be excluded with exclude_read_actions.
When archive is present, the generated archive.read_action is excluded from archive
filtering (but not latest filtering); user-declared actions can be excluded with from
archive filtering with archive.exclude_read_actions.
An action name only needs to appear in one of the two exclusion lists; the top-level one is checked first and is a full bypass, so an action listed in both gets the top-level treatment.
Summary
Functions
Callback implementation for Ash.Resource.Preparation.init/1.
Callback implementation for Ash.Resource.Preparation.supports/1.
Functions
Callback implementation for Ash.Resource.Preparation.init/1.
Callback implementation for Ash.Resource.Preparation.supports/1.