AshVersioned. ReferenceActorValue
(ash_versioned v0.1.0)
The default transform function for a reference_actor field.
Summary
Functions
Returns the identity value for the provided actor or an error message.
Functions
Returns the identity value for the provided actor or an error message.
Ash resources are resolved using the primary key, if it resolves to a single value
(composite primary keys are not supported). When the Ash resource is an
AshVersioned.Resource, it uses the resource identity attribute.
All other actor values (except nil) are checked for string conversion
(String.Chars) and an error is returned if it cannot be converted.