AshVersioned. Resource. Archive
(ash_versioned v0.1.0)
Represents the archive entity declared inside the versioning DSL section of
AshVersioned.Resource.
A resource is archivable when the archive entity is declared.